@@ -9,17 +9,16 @@ from django.db.models.fields.files import FieldFile, FileField, ImageField
 from django.urls import reverse
 
 from ..conf import settings
-from .dynamic_storage import (DynamicStorageFieldFile, DynamicStorageFileField,
-                              DynamicStorageImageField,
-                              DynamicStorageImageFieldFile, FileFieldMixin)
+from .dynamic_storage import DynamicStorageFieldFile, DynamicStorageFileField, DynamicStorageImageField, DynamicStorageImageFieldFile, FileFieldMixin
 
 log = logging.getLogger(__name__)
 
 
 class EncryptedFile(BytesIO):
     """Wrapper class which encrypts the content supplied with the fernet specified on initialization"""
+
     def __init__(self, content, fernet):
-        if content and hasattr(content, 'read'):
+        if content and hasattr(content, "read"):
             content = content.read()
         if content:
             BytesIO.__init__(self, fernet.encrypt(content))
@@ -29,8 +28,9 @@ class EncryptedFile(BytesIO):
 
 class DecryptedFile(BytesIO):
     """Wrapper class around `io.BytesIO` that augments the initialization of the class to decrypt contents if a fernet is passed in to the constructor"""
+
     def __init__(self, content, fernet):
-        if content and hasattr(content, 'read'):
+        if content and hasattr(content, "read"):
             content = content.read()
         if content:
             BytesIO.__init__(self, fernet.decrypt(content))
@@ -41,9 +41,10 @@ class DecryptedFile(BytesIO):
 class EncryptedFieldFile(DynamicStorageFieldFile):
     def __init__(self, instance, field, name, **kwargs):
         self.fernet = getattr(field, "fernet", None)
+        self._get_url = getattr(field, "get_url", None)
         super().__init__(instance, field, name)
         if callable(self.fernet):
-            log.debug('EncryptedFieldFile init - fernet {} is callable'.format(self.fernet))
+            log.debug("EncryptedFieldFile init - fernet {} is callable".format(self.fernet))
             self.fernet = self.fernet(instance)
         if not self.fernet:
             raise RuntimeError("Encryption Fernet details not provided for this instance of a EncryptedFieldFile")
@@ -56,24 +57,16 @@ class EncryptedFieldFile(DynamicStorageFieldFile):
     def fernet(self, val):
         self._fernet = val
 
-    def _get_url(self):
-        if settings.DS_DOWNLOAD_URL_NAME:
-            url_args = []
-            for k in settings.DS_DOWNLOAD_URL_ARG_NAMES:
-                val = str(getattr(self.instance, k, None))
-                if val:
-                    url_args.append(val)
-            return reverse(settings.DS_DOWNLOAD_URL_NAME, args=url_args)
-        return None
-
     def get_decrypted(self):
         if self.fernet:
-            log.debug('Fernet type is {}'.format(type(self.fernet)))
-            return DecryptedFile(self.open('rb'), self.fernet)
+            log.debug("Fernet type is {}".format(type(self.fernet)))
+            return DecryptedFile(self.open("rb"), self.fernet)
         else:
-            return BytesIO(self.open('rb').read())
+            return BytesIO(self.open("rb").read())
 
-    url = property(_get_url)
+    @property
+    def url(self):
+        return self._get_url(self.instance) if self._get_url else None
 
     def deconstruct(self):
         name, path, args, kwargs = super().deconstruct()
